__float22bfloat162_rz
Applicability
Product |
Supported |
|---|---|
Atlas 350 Accelerator Card |
√ |
x |
|
x |
|
x |
|
x |
|
x |
|
x |
Function Usage
Converts the two components of float2 data to bfloat16 precision in line with the CAST_TRUNC mode and returns the converted bfloat16x2_t data.
Prototype
1 | inline bfloat16x2_t __float22bfloat162_rz(const float2 x) |
Parameters
Parameter |
Input/Output |
Description |
|---|---|---|
x |
Input |
Source operand. |
Returns
The bfloat16x2_t data converted from the two input components in line with the CAST_TRUNC mode.
Restrictions
For SIMT programming, this API is not supported.
Header File to Be Included
To use this API, the simt_api/asc_bf16.h header file must be included.
1 | #include "simt_api/asc_bf16.h" |
Examples
For SIMD and SIMT programming:
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 | // Use small vectors to improve data movement efficiency. __simt_vf__ __launch_bounds__(1024) inline void simt_float22bfloat162_rz(__gm__ float2* input, __gm__ bfloat16x2_t* output, uint32_t input_total_length) { uint32_t idx = blockIdx.x * blockDim.x + threadIdx.x; // Each thread processes one piece of float2 data, that is, two pieces of float data. Therefore, threads with idx greater than or equal to input_total_length/2 do not process data. if (idx >= input_total_length / 2) { return; } output[idx] = __float22bfloat162_rz(input[idx]); } __global__ __vector__ void cast_kernel(__gm__ float* input, __gm__ bfloat16_t* output, uint32_t input_total_length) { asc_vf_call<simt_float22bfloat162_rz>(dim3(1024), (__gm__ float2*)input, (__gm__ bfloat16x2_t*)output, input_total_length); } |
Parent topic: Type Conversion